@@ -42,6 +42,7 @@ class GSPeerConnectionBroadcasterPiCaller:
         self.oncommand = oncommand
 
     async def startSocket(self):
+        self._logger.debug("start broadcast socket")
         await GSPeerConnectionBroadcasterPiSocket.create(self.sio,
                                                          self.gsdbs,
                                                          self.camera,
@@ -69,6 +70,7 @@ class GSPeerConnectionBroadcasterPiSocket:
     @classmethod
     async def create(cls, sio, gsdbs, camera, oncommand):
         self = GSPeerConnectionBroadcasterPiSocket()
+
         self.rtconfiList = []
 
         self.gsdbs = gsdbs
@@ -114,6 +116,7 @@ class GSPeerConnectionBroadcasterPiSocket:
 
         @self.sio.event
         async def watcher(id, description):
+            self._logger.debug("watcher found")
             if type(description) == str:
                 description = ast.literal_eval(description)
             desc = type('new_dict', (object,), description)
@@ -182,7 +185,6 @@ class GSPeerConnectionBroadcasterPiSocket:
                 self.peerConnections.pop(id, None)
 
 
-
         @self.sio.event
         async def disconnect():
             self._logger.info('disconnected from server')
